@@ -1485,10 +1485,16 @@ c    *********************
 #include "Zcnfig.h"
 #include "ZepDraw.h"
       integer i, j, w
+      record /epPos/ org
+      record /ep3Vec/ abc
 
 c         read config file
       call eprcnf(configFile)
 
+      call epqcnf(org, abc)
+      write(0, *) 'Bounding box of the world'
+      write(0, '(a,1p,3g15.7)') ' origing=', org
+      write(0, '(a,1p,3g15.7)') ' box x y z length=',abc
 
       NumComp = Det.nct
       NumWorld = Det.nworld
